@@ -5,7 +5,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2019	PgPool Global Development Group
+ * Copyright (c) 2003-2020	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -62,7 +62,6 @@
 #include "auth/pool_hba.h"
 #include "utils/pool_stream.h"
 
-char		remote_ps_data[NI_MAXHOST]; /* used for set_ps_display */
 static POOL_CONNECTION_POOL_SLOT * slot;
 static volatile sig_atomic_t reload_config_request = 0;
 static volatile sig_atomic_t restart_request = 0;
@@ -239,6 +238,7 @@ establish_persistent_connection(int node)
 	static time_t auto_failback_interval = 0; /* resume time of auto_failback */
 	bool		check_failback = false;
 	time_t		now;
+	char		*dbname;
 
 	bkinfo = pool_get_node_info(node);
 
@@ -269,7 +269,9 @@ establish_persistent_connection(int node)
 	 * If database is not specified, "postgres" database is assumed.
 	 */
 	if (*pool_config->health_check_params[node].health_check_database == '\0')
-		pool_config->health_check_params[node].health_check_database = "postgres";
+		dbname = "postgres";
+	else
+		dbname = pool_config->health_check_params[node].health_check_database;
 
 	/*
 	 * Try to connect to the database.
@@ -298,7 +300,7 @@ establish_persistent_connection(int node)
 
 			slot = make_persistent_db_connection_noerror(node, bkinfo->backend_hostname,
 														 bkinfo->backend_port,
-														 pool_config->health_check_params[node].health_check_database,
+														 dbname,
 														 pool_config->health_check_params[node].health_check_user,
 														 password ? password : "", false);
 
@@ -488,7 +490,7 @@ check_backend_down_request(int node, bool done_requests)
 		ereport(WARNING,
 				(errmsg("check_backend_down_request: failed to open file %s",
 						backend_down_request_file),
-				 errdetail("\"%s\"", strerror(errno))));
+				 errdetail("%m")));
 		return false;
 	}
 
@@ -552,7 +554,7 @@ check_backend_down_request(int node, bool done_requests)
 		ereport(WARNING,
 				(errmsg("check_backend_down_request: failed to open file for writing %s",
 						backend_down_request_file),
-				 errdetail("\"%s\"", strerror(errno))));
+				 errdetail("%m")));
 		return false;
 	}
 
@@ -561,7 +563,7 @@ check_backend_down_request(int node, bool done_requests)
 		ereport(WARNING,
 				(errmsg("check_backend_down_request: failed to write %s",
 						backend_down_request_file),
-				 errdetail("\"%s\"", strerror(errno))));
+				 errdetail("%m")));
 		fclose(fd);
 		return false;
 	}
