@@ -399,7 +399,7 @@ pool_backend_timer(void)
 	now = time(NULL);
 
 	ereport(DEBUG1,
-			(errmsg("backend timer handler called at%ld", now)));
+			(errmsg("backend timer handler called at %ld", now)));
 
 	for (i = 0; i < pool_config->max_pool; i++, p++)
 	{
@@ -515,7 +515,7 @@ connect_unix_domain_socket_by_port(int port, char *socket_dir, bool retry)
 	{
 		ereport(LOG,
 				(errmsg("failed to connect to PostgreSQL server by unix domain socket"),
-				 errdetail("create socket failed with error \"%s\"", strerror(errno))));
+				 errdetail("create socket failed with error \"%m\"")));
 		return -1;
 	}
 
@@ -542,7 +542,7 @@ connect_unix_domain_socket_by_port(int port, char *socket_dir, bool retry)
 			close(fd);
 			ereport(LOG,
 					(errmsg("failed to connect to PostgreSQL server by unix domain socket"),
-					 errdetail("connect to \"%s\" failed with error \"%s\"", addr.sun_path, strerror(errno))));
+					 errdetail("connect to \"%s\" failed with error \"%m\"", addr.sun_path)));
 
 			return -1;
 		}
@@ -612,7 +612,8 @@ connect_with_timeout(int fd, struct addrinfo *walk, char *host, int port, bool r
 			if (errno != EINPROGRESS && errno != EALREADY)
 			{
 				ereport(LOG,
-						(errmsg("failed to connect to PostgreSQL server on \"%s:%d\" with error \"%s\"", host, port, strerror(errno))));
+						(errmsg("failed to connect to PostgreSQL server on \"%s:%d\"", host, port),
+						 errdetail("%m")));
 				return false;
 			}
 
@@ -672,7 +673,8 @@ connect_with_timeout(int fd, struct addrinfo *walk, char *host, int port, bool r
 					{
 						/* Solaris returns error in this case */
 						ereport(LOG,
-								(errmsg("failed to connect to PostgreSQL server on \"%s:%d\", getsockopt() failed with error \"%s\"", host, port, strerror(errno))));
+								(errmsg("failed to connect to PostgreSQL server on \"%s:%d\", getsockopt() failed", host, port),
+								 errdetail("%m")));
 
 						return false;
 					}
@@ -681,7 +683,8 @@ connect_with_timeout(int fd, struct addrinfo *walk, char *host, int port, bool r
 					if (error != 0)
 					{
 						ereport(LOG,
-								(errmsg("failed to connect to PostgreSQL server on \"%s:%d\", getsockopt() detected error \"%s\"", host, port, strerror(error))));
+								(errmsg("failed to connect to PostgreSQL server on \"%s:%d\", getsockopt() failed", host, port),
+								 errdetail("%m")));
 						return false;
 					}
 				}
@@ -728,7 +731,7 @@ connect_with_timeout(int fd, struct addrinfo *walk, char *host, int port, bool r
 				{
 					ereport(LOG,
 							(errmsg("failed to connect to PostgreSQL server on \"%s:%d\" using INET socket", host, port),
-							 errdetail("select() system call failed with an error \"%s\"", strerror(errno))));
+							 errdetail("select() system call failed with error \"%m\"")));
 				}
 				close(fd);
 				return false;
@@ -763,7 +766,8 @@ connect_inet_domain_socket_by_port(char *host, int port, bool retry)
 	if (asprintf(&portstr, "%d", port) == -1)
 	{
 		ereport(WARNING,
-				(errmsg("failed to connect to PostgreSQL server, asprintf() failed with error \"%s\"", strerror(errno))));
+				(errmsg("failed to connect to PostgreSQL server, asprintf() failed"),
+				 errdetail("%m")));
 
 		return -1;
 	}
@@ -789,7 +793,8 @@ connect_inet_domain_socket_by_port(char *host, int port, bool retry)
 		if (fd < 0)
 		{
 			ereport(WARNING,
-					(errmsg("failed to connect to PostgreSQL server, socket() failed with error \"%s\"", strerror(errno))));
+					(errmsg("failed to connect to PostgreSQL server, socket() failed"),
+					 errdetail("%m")));
 			continue;
 		}
 
@@ -799,7 +804,8 @@ connect_inet_domain_socket_by_port(char *host, int port, bool retry)
 					   sizeof(on)) < 0)
 		{
 			ereport(WARNING,
-					(errmsg("failed to connect to PostgreSQL server, setsockopt() failed with error \"%s\"", strerror(errno))));
+					(errmsg("failed to connect to PostgreSQL server, setsockopt() failed"),
+					 errdetail("%m")));
 
 			close(fd);
 			freeaddrinfo(res);
